==> groovyscript-1.3.0-sources.jar: com/cleanroommc/groovyscript/compat/content/GroovyBlock.java <==
package com.cleanroommc.groovyscript.compat.content;

import com.cleanroommc.groovyscript.GroovyScript;
import com.cleanroommc.groovyscript.api.GroovyBlacklist;
import com.cleanroommc.groovyscript.api.GroovyLog;
import com.cleanroommc.groovyscript.compat.vanilla.VanillaModule;
import com.cleanroommc.groovyscript.helper.JsonHelper;
import com.cleanroommc.groovyscript.sandbox.FileUtil;
import com.google.gson.JsonObject;
import it.unimi.dsi.fastutil.objects.Object2ObjectLinkedOpenHashMap;
import net.minecraft.block.Block;
import net.minecraft.block.SoundType;
import net.minecraft.block.material.Material;
import net.minecraft.client.renderer.block.model.ModelBakery;
import net.minecraft.client.renderer.block.model.ModelResourceLocation;
import net.minecraft.item.Item;
import net.minecraft.item.ItemBlock;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.client.model.ModelLoader;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;
import net.minecraftforge.registries.IForgeRegistry;
import org.apache.commons.lang3.tuple.Pair;
import org.jetbrains.annotations.ApiStatus;

import java.io.File;
import java.util.Map;

public class GroovyBlock extends Block {

    private static boolean initialised;
    private static final String nullTranslationKey = "tile.null";

    private static final Map<String, Pair<Block, ItemBlock>> BLOCKS = new Object2ObjectLinkedOpenHashMap<>();

    @GroovyBlacklist
    public static void register(Block block, ItemBlock itemBlock) {
        if (initialised) {
            GroovyLog.get().errorMC("Items must registered in preInit. Tried to register {} too late!", block.getRegistryName());
            return;
        }
        if (itemBlock.getBlock() != block) {
            GroovyLog.get().exception(new IllegalArgumentException("The item block must the item form of the block!"));
            return;
        }
        ResourceLocation itemLoc = itemBlock.getRegistryName();
        ResourceLocation blockLoc = block.getRegistryName();
        if (itemLoc == null || !itemLoc.equals(blockLoc) || BLOCKS.containsKey(itemLoc.getPath())) {
            GroovyLog.get().exception(new IllegalArgumentException("The registry name of the block and the item must be non-null and equal!"));
            return;
        }
        BLOCKS.put(itemLoc.getPath(), Pair.of(block, itemBlock));
    }

    @GroovyBlacklist
    @ApiStatus.Internal
    public static void initItems(IForgeRegistry<Item> registry) {
        for (Pair<Block, ItemBlock> pair : BLOCKS.values()) {
            registry.register(pair.getRight());
            checkItemModel(pair.getRight().getRegistryName());
        }
    }

    @GroovyBlacklist
    @ApiStatus.Internal
    public static void initBlocks(IForgeRegistry<Block> registry) {
        for (Pair<Block, ItemBlock> pair : BLOCKS.values()) {
            Block block = pair.getLeft();
            registry.register(block);
            checkBlockModel(block.getRegistryName());
            if (block.getTranslationKey().equals(nullTranslationKey)) {
                block.setTranslationKey(block.getRegistryName().getNamespace() + "." + block.getRegistryName().getPath());
            }
        }
        initialised = true;
    }

    @GroovyBlacklist
    @ApiStatus.Internal
    @SideOnly(Side.CLIENT)
    public static void registerModels() {
        for (Pair<Block, ItemBlock> pair : BLOCKS.values()) {
            Item item = pair.getRight();
            ResourceLocation rl = item.getRegistryName();
            ModelBakery.registerItemVariants(item, rl);
            ModelResourceLocation mrl = new ModelResourceLocation(rl, "inventory");
            ModelLoader.setCustomModelResourceLocation(item, 0, mrl);
        }
    }

    private final ItemBlock itemBlock;

    public GroovyBlock(String name, Material blockMaterialIn) {
        super(blockMaterialIn);
        this.itemBlock = new ItemBlock(this);
        setRegistryName(GroovyScript.getRunConfig().getPackId(), name);
        this.itemBlock.setRegistryName(GroovyScript.getRunConfig().getPackId(), name);
        setHardness(2.0F);
        setResistance(10.0F);
        setSoundType(SoundType.STONE);
        if (VanillaModule.INSTANCE.content.getDefaultTab() != null) {
            setCreativeTab(VanillaModule.INSTANCE.content.getDefaultTab());
        }
    }

    public GroovyBlock register() {
        register(this, this.itemBlock);
        return this;
    }

    private static void checkBlockModel(ResourceLocation loc) {
        File file = FileUtil.makeFile(GroovyScript.getResourcesFile().getPath(), loc.getNamespace(), "blockstates", loc.getPath() + ".json");
        if (!file.exists()) {
            JsonObject stateJson = new JsonObject();
            JsonObject variantsJson = new JsonObject();
            JsonObject modelJson = new JsonObject();
            modelJson.addProperty("model", loc.toString());
            variantsJson.add("normal", modelJson);
            stateJson.add("variants", variantsJson);
            JsonHelper.saveJson(file, stateJson);
        }

        file = FileUtil.makeFile(GroovyScript.getResourcesFile().getPath(), loc.getNamespace(), "models", "block", loc.getPath() + ".json");
        if (!file.exists()) {
            JsonObject modelJson = new JsonObject();
            modelJson.addProperty("parent", "block/cube_all");
            JsonObject texturesJson = new JsonObject();
            texturesJson.addProperty("all", loc.getNamespace() + ":blocks/" + loc.getPath());
            modelJson.add("textures", texturesJson);
            JsonHelper.saveJson(file, modelJson);
        }
    }

    private static void checkItemModel(ResourceLocation loc) {
        File file = FileUtil.makeFile(GroovyScript.getResourcesFile().getPath(), loc.getNamespace(), "models", "item", loc.getPath() + ".json");
        if (!file.exists()) {
            JsonObject modelJson = new JsonObject();
            modelJson.addProperty("parent", loc.getNamespace() + ":block/" + loc.getPath());
            JsonHelper.saveJson(file, modelJson);
        }
    }
}

==> groovyscript-1.3.3-sources.jar: com/cleanroommc/groovyscript/compat/content/GroovyBlock.java <==
package com.cleanroommc.groovyscript.compat.content;

import com.cleanroommc.groovyscript.GroovyScript;
import com.cleanroommc.groovyscript.api.GroovyBlacklist;
import com.cleanroommc.groovyscript.api.GroovyLog;
import com.cleanroommc.groovyscript.api.documentation.annotations.*;
import com.cleanroommc.groovyscript.compat.vanilla.VanillaModule;
import com.cleanroommc.groovyscript.helper.JsonHelper;
import com.cleanroommc.groovyscript.sandbox.FileUtil;
import com.google.gson.JsonObject;
import it.unimi.dsi.fastutil.objects.Object2ObjectLinkedOpenHashMap;
import net.minecraft.block.Block;
import net.minecraft.block.SoundType;
import net.minecraft.block.material.Material;
import net.minecraft.client.renderer.block.model.ModelBakery;
import net.minecraft.client.renderer.block.model.ModelResourceLocation;
import net.minecraft.item.Item;
import net.minecraft.item.ItemBlock;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.client.model.ModelLoader;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;
import net.minecraftforge.registries.IForgeRegistry;
import org.apache.commons.lang3.tuple.Pair;
import org.jetbrains.annotations.ApiStatus;

import java.io.File;
import java.util.Map;

@Property(property = "displayOnCreativeTab")
//@Property(property = "fullBlock")//fieldOnly
@Property(property = "lightOpacity")
//@Property(property = "translucent")//fieldOnly
@Property(property = "lightValue")
//@Property(property = "useNeighborBrightness")//protected fieldOnly
@Property(property = "blockHardness", defaultValue = "2.0f")
@Property(property = "blockResistance", defaultValue = "10.0f")
//@Property(property = "enableStats")//protected
@Property(property = "needsRandomTick")
//@Property(property = "hasTileEntity")//protected fieldOnly
@Property(property = "blockSoundType", defaultValue = "SoundType.STONE")
//@Property(property = "blockParticleGravity")//fieldOnly
//@Property(property = "slipperiness")//not a builder method
//@Property(property = "defaultBlockState")//protected and not a builder method
@Property(property = "translationKey", defaultValue = "registryName", value = "groovyscript.wiki.minecraft.content.item.translationKey.value")
@RecipeBuilderOverride(method = {
        @RecipeBuilderMethodDescription(method = "setSoundType", field = "blockSoundType"),
        @RecipeBuilderMethodDescription(method = "setLightOpacity", field = "lightOpacity"),
        @RecipeBuilderMethodDescription(method = "setLightLevel", field = "lightValue"),//15x float
        @RecipeBuilderMethodDescription(method = "setResistance", field = "blockResistance"),//3x float
        @RecipeBuilderMethodDescription(method = "setHardness", field = {
                "blockHardness", "blockResistance"
        }, description = "groovyscript.wiki.minecraft.content.block.setHardness.description"),//block resistance is increased to hardness*5
        @RecipeBuilderMethodDescription(method = "setBlockUnbreakable", field = {
                "blockHardness", "blockResistance"
        }, description = "groovyscript.wiki.minecraft.content.block.setBlockUnbreakable.description"),
        @RecipeBuilderMethodDescription(method = "setTickRandomly", field = "needsRandomTick"),
        @RecipeBuilderMethodDescription(method = "setTranslationKey", field = "translationKey"),
//        @RecipeBuilderMethodDescription(method = "setDefaultState", field = "defaultBlockState"),//protected and not a builder method
//        @RecipeBuilderMethodDescription(method = "disableStats", field = "enableStats"),//protected
//        @RecipeBuilderMethodDescription(method = "setDefaultSlipperiness", field = "slipperiness"),//not a builder method
        @RecipeBuilderMethodDescription(method = "setCreativeTab", field = "displayOnCreativeTab"),
})
public class GroovyBlock extends Block {

    private static boolean initialised;
    private static final String nullTranslationKey = "tile.null";

    private static final Map<String, Pair<Block, ItemBlock>> BLOCKS = new Object2ObjectLinkedOpenHashMap<>();

    @GroovyBlacklist
    public static void register(Block block, ItemBlock itemBlock) {
        if (initialised) {
            GroovyLog.get().errorMC("Items must registered in preInit. Tried to register {} too late!", block.getRegistryName());
            return;
        }
        if (itemBlock.getBlock() != block) {
            GroovyLog.get().exception(new IllegalArgumentException("The item block must the item form of the block!"));
            return;
        }
        ResourceLocation itemLoc = itemBlock.getRegistryName();
        ResourceLocation blockLoc = block.getRegistryName();
        if (itemLoc == null || !itemLoc.equals(blockLoc) || BLOCKS.containsKey(itemLoc.getPath())) {
            GroovyLog.get().exception(new IllegalArgumentException("The registry name of the block and the item must be non-null and equal!"));
            return;
        }
        BLOCKS.put(itemLoc.getPath(), Pair.of(block, itemBlock));
    }

    @GroovyBlacklist
    @ApiStatus.Internal
    public static void initItems(IForgeRegistry<Item> registry) {
        for (Pair<Block, ItemBlock> pair : BLOCKS.values()) {
            registry.register(pair.getRight());
            checkItemModel(pair.getRight().getRegistryName());
        }
    }

    @GroovyBlacklist
    @ApiStatus.Internal
    public static void initBlocks(IForgeRegistry<Block> registry) {
        for (Pair<Block, ItemBlock> pair : BLOCKS.values()) {
            Block block = pair.getLeft();
            registry.register(block);
            checkBlockModel(block.getRegistryName());
            if (block.getTranslationKey().equals(nullTranslationKey)) {
                block.setTranslationKey(block.getRegistryName().getNamespace() + "." + block.getRegistryName().getPath());
            }
        }
        initialised = true;
    }

    @GroovyBlacklist
    @ApiStatus.Internal
    @SideOnly(Side.CLIENT)
    public static void registerModels() {
        for (Pair<Block, ItemBlock> pair : BLOCKS.values()) {
            Item item = pair.getRight();
            ResourceLocation rl = item.getRegistryName();
            ModelBakery.registerItemVariants(item, rl);
            ModelResourceLocation mrl = new ModelResourceLocation(rl, "inventory");
            ModelLoader.setCustomModelResourceLocation(item, 0, mrl);
        }
    }

    private final ItemBlock itemBlock;

    public GroovyBlock(String name, Material blockMaterialIn) {
        super(blockMaterialIn);
        this.itemBlock = new ItemBlock(this);
        setRegistryName(GroovyScript.getRunConfig().getPackId(), name);
        this.itemBlock.setRegistryName(GroovyScript.getRunConfig().getPackId(), name);
        setHardness(2.0F);
        setResistance(10.0F);
        setSoundType(SoundType.STONE);
        if (VanillaModule.INSTANCE.content.getDefaultTab() != null) {
            setCreativeTab(VanillaModule.INSTANCE.content.getDefaultTab());
        }
    }

    @RecipeBuilderRegistrationMethod(description = "groovyscript.wiki.minecraft.content.block.register.description")
    public GroovyBlock register() {
        register(this, this.itemBlock);
        return this;
    }

    private static void checkBlockModel(ResourceLocation loc) {
        File file = FileUtil.makeFile(GroovyScript.getResourcesFile().getPath(), loc.getNamespace(), "blockstates", loc.getPath() + ".json");
        if (!file.exists()) {
            JsonObject stateJson = new JsonObject();
            JsonObject variantsJson = new JsonObject();
            JsonObject modelJson = new JsonObject();
            modelJson.addProperty("model", loc.toString());
            variantsJson.add("normal", modelJson);
            stateJson.add("variants", variantsJson);
            JsonHelper.saveJson(file, stateJson);
        }

        file = FileUtil.makeFile(GroovyScript.getResourcesFile().getPath(), loc.getNamespace(), "models", "block", loc.getPath() + ".json");
        if (!file.exists()) {
            JsonObject modelJson = new JsonObject();
            modelJson.addProperty("parent", "block/cube_all");
            JsonObject texturesJson = new JsonObject();
            texturesJson.addProperty("all", loc.getNamespace() + ":blocks/" + loc.getPath());
            modelJson.add("textures", texturesJson);
            JsonHelper.saveJson(file, modelJson);
        }
    }

    private static void checkItemModel(ResourceLocation loc) {
        File file = FileUtil.makeFile(GroovyScript.getResourcesFile().getPath(), loc.getNamespace(), "models", "item", loc.getPath() + ".json");
        if (!file.exists()) {
            JsonObject modelJson = new JsonObject();
            modelJson.addProperty("parent", loc.getNamespace() + ":block/" + loc.getPath());
            JsonHelper.saveJson(file, modelJson);
        }
    }
}
